---
title: "Post by @kepano"
author: "@kepano"
site: "X (Twitter)"
source: "https://x.com/kepano/status/1675626836821409792"
language: "en"
word_count: 377
---

**kepano** @kepano

File over app

*File over app* is a philosophy: if you want to create digital artifacts that last, they must be files you can control, in formats that are easy to retrieve and read. Use tools that give you this freedom.

*File over app* is an appeal to tool makers: accept that all software is ephemeral, and give people ownership over their data.

In the fullness of time, the files you create are more important than the tools you use to create them. Apps are ephemeral, but your files have a chance to last.

The pyramids of Egypt contain hieroglyphs that were chiseled in stone thousands of years ago. The ideas hieroglyphs convey are more important than the type of chisel that was used to carve them.

The world is filled with ideas from generations past, transmitted through many mediums, from clay tablets to manuscripts, paintings, sculptures, and tapestries. These artifacts are objects that you can touch, hold, own, store, preserve, and look at. To read something written on paper all you need is eyeballs.

Today, we are creating innumerable digital artifacts, but most of these artifacts are out of our control. They are stored on servers, in databases, gated behind an internet connection, and login to a cloud service. Even the files on your hard drive use proprietary formats that make them incompatible with older systems.

Paraphrasing something I wrote recently:

> If you want your writing to still be readable on a computer from the 2060s or 2160s, it’s important that your notes can be read on a computer from the 1960s.

You should want the files you create to be durable, not only for posterity, but also for your future self. You never know when you might want to go back to something you created years or decades ago. Don’t lock your data into a format you can’t retrieve.

These days I write using an app I help make called Obsidian (@obsdmd), but it’s a delusion to think it will last forever. The app will eventually become obsolete. It’s the plain text files I create that are designed to last. Who knows if anyone will want to read them besides me, but *future me* is enough of an audience to make it worthwhile.

![](https://pbs.twimg.com/media/F0EFg68acAMtnMQ.png?name=orig) ![](https://pbs.twimg.com/media/F0EFg7CaIAEcG6f.png?name=orig)